@@ -11,8 +11,8 @@ import (
 
 // infoCmd displays macpine machine info
 var infoCmd = &cobra.Command{
-	Use:   "info NAME",
-	Short: "Display information about instances.",
+	Use:   "info <instance>",
+	Short: "Display information about an instance.",
 	Run:   macpineInfo,
 
 	ValidArgsFunction:     host.AutoCompleteVMNames,
@@ -21,7 +21,7 @@ var infoCmd = &cobra.Command{
 
 func macpineInfo(cmd *cobra.Command, args []string) {
 	if len(args) == 0 {
-		log.Fatal("missing VM name")
+		log.Fatal("missing instance name")
 	}
 
 	for _, vmName := range args {
